<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Connect to the database
include '../config/database2.php';

   // Validate the API key
$expected_api_key = "8L14irhDOhBUffrmiv2kqUSoSpeIK9D7JYDmsPVS9-M";

$received_api_key = isset($_SERVER['HTTP_AUTH']) ? trim($_SERVER['HTTP_AUTH']) : '';


if ($received_api_key !== $expected_api_key) {
    $response = [
        'success' => false,
        'message' => "Invalid API Key."
    ];
    echo json_encode($response);
    exit; // Terminate the script if the API key is invalid
}

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Get the customer ID
$customerid = $_GET['customerid'];

// Fetch the order ID and items for the given customer
$sql = "SELECT Orders.orderID, Orders.date, OrdersEntry.itemID
        FROM Orders
        INNER JOIN OrdersEntry ON Orders.orderID = OrdersEntry.orderID
        WHERE Orders.customerID = ? AND Orders.Confirmed = 1 AND Orders.Delivered = 1";
$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $customerid);
$stmt->execute();
$ordersResult = $stmt->get_result();
$orders = $ordersResult->fetch_all(MYSQLI_ASSOC);

$groupedItems = array();

// Fetch additional information for each order item
foreach ($orders as $order) {
    $orderID = $order['orderID'];
    $orderDate = $order['date'];
    $itemID = $order['itemID'];

    $itemSql = "SELECT item.id AS itemID, item.description, item.longdescription, item.departmentID,item.is_serial, department.Name AS department_name, inventorylocationitems.price, inventorylocationitems.cost, inventorylocationitems.quantity,CONCAT('https://admin.kassmatt.com/dist/img/items/', item.ID, '/', productimages.pic1) AS imageUrl
            FROM inventorylocationitems
            INNER JOIN item ON inventorylocationitems.itemID = item.id
            LEFT JOIN productimages ON inventorylocationitems.itemID = productimages.itemID
            LEFT JOIN department ON item.departmentID = department.ID
            WHERE item.id = ? AND inventorylocationitems.quantity > 0 AND department.Name IS NOT NULL AND productimages.pic1 IS NOT NULL AND productimages.pic1 != '' ";
    $itemStmt = $conn->prepare($itemSql);
    $itemStmt->bind_param('i', $itemID);
    $itemStmt->execute();
    $itemResult = $itemStmt->get_result();
    $item = $itemResult->fetch_assoc();

    if ($item) {
        if (!isset($groupedItems[$orderID])) {
            $groupedItems[$orderID] = array(
                'orderID' => $orderID,
                'date' => $orderDate,
                'items' => array(),
            );
        }

        $groupedItems[$orderID]['items'][] = array(
            'id' => '224203' . $item['cost'] . '+' . $item['itemID'] . '+' . $item['price'],
            'itemID' => $item['itemID'],
            'description' => $item['description'],
            'longdescription' => $item['longdescription'],
            'price' => $item['price'],
            'cost' => $item['cost'],
            'quantity' => $item['quantity'],
            'imageUrl' => $item['imageUrl'],
            "serial" =>  $item['is_serial']
        );
    }
}

// Convert the grouped item data into a simple array
$groupedItems = array_values($groupedItems);

// Return the item data
echo json_encode($groupedItems);

// Close the connections and statements
$itemStmt->close();
$stmt->close();
$conn->close();
?>
