<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");
header("Access-Control-Allow-Credentials: true");

// Connect to the database
include '../config/database3.php';
include '../config/url.php';

  // Validate the API key
$expected_api_key = "8L14irhDOhBUffrmiv2kqUSoSpeIK9D7JYDmsPVS9-M";

$received_api_key = isset($_SERVER['HTTP_AUTH']) ? trim($_SERVER['HTTP_AUTH']) : '';


if ($received_api_key !== $expected_api_key) {
    $response = [
        'success' => false,
        'message' => "Invalid API Key."
    ];
    echo json_encode($response);
    exit; // Terminate the script if the API key is invalid
}

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Get the branch ID
$branchId = $_GET['branchid'];

// Pagination parameters
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Get the requested page, default is 1
$itemsPerPage = 9;
$offset = ($page - 1) * $itemsPerPage;


$sql = "SELECT 
    item.ID AS itemID, 
    item.ItemLookupCode,
    item.BinLocation,
    item.Description,
    item.DepartmentID,
    item.CategoryID,
    inventorylocationitems.Price, 
    inventorylocationitems.Quantity,
    inventorylocationitems.InventoryLocation,
    'product' AS type,
    CONCAT('$url', item.ID, '/', productimages.pic1) AS imageUrl,
    CASE 
        WHEN serial.ItemID IS NOT NULL AND serial.ItemID > 0 THEN 1
        ELSE 0
    END AS is_serial
    
FROM 
    inventorylocationitems
    
INNER JOIN 
    item ON inventorylocationitems.ItemDBID = item.id
    
LEFT JOIN 
    productimages ON item.ID = productimages.itemID

LEFT JOIN 
    serial ON serial.ItemID = item.ID AND serial.ItemID > 0
    
WHERE 
    inventorylocationitems.InventoryLocation = ?
    AND inventorylocationitems.Quantity > 0
    AND item.Inactive = 0
    
   ORDER BY inventorylocationitems.updated_at DESC";


$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $branchId);
$stmt->execute();
$result = $stmt->get_result();

// Count the total rows
$totalCount = $result->num_rows;

// Now you can fetch the items with pagination
$sqlWithLimit = $sql . " LIMIT ?,?";
$stmtWithLimit = $conn->prepare($sqlWithLimit);
$stmtWithLimit->bind_param('iii', $branchId, $offset, $itemsPerPage);
$stmtWithLimit->execute();
$resultWithLimit = $stmtWithLimit->get_result();
$items = $resultWithLimit->fetch_all(MYSQLI_ASSOC);



// Prepare the response data
$response = [
    'total_pages' => ceil($totalCount / $itemsPerPage),
    'current_page' => $page,
    'total_items' => $totalCount,
    'items' => $items
];

// Return the API response
echo json_encode($response);

$conn->close();
?>
