<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Get the cell parameter from the request URL
$userid = $_GET['userid'];
$branchid = $_GET['branchid'];

// Validate the API key
$expected_api_key = "8L14irhDOhBUffrmiv2kqUSoSpeIK9D7JYDmsPVS9-M";
$received_api_key = isset($_SERVER['HTTP_AUTH']) ? trim($_SERVER['HTTP_AUTH']) : '';

if ($received_api_key !== $expected_api_key) {
    $response = [
        'success' => false,
        'message' => "Invalid API Key."
    ];
    echo json_encode($response);
    exit; // Terminate the script if the API key is invalid
}

// Connect to the database
include '../config/database3.php';

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Fetch userAddress
$stmtUserAddress = $conn->prepare("
    SELECT userAddress.*, streetAddresses.street AS regionname, streetAddresses.shippingFee
    FROM userAddress
    JOIN streetAddresses ON userAddress.region = streetAddresses.id
    WHERE userAddress.userid = ? AND is_default = 1 LIMIT 1
");

$stmtUserAddress->bind_param("i", $userid);
$stmtUserAddress->execute();
$resultUserAddress = $stmtUserAddress->get_result();

// If no default address was found, return null
if ($resultUserAddress->num_rows == 0) {
    $response = null;
} else {
    // Otherwise, create an address object
    $rowUserAddress = $resultUserAddress->fetch_assoc();
    $addressUserAddress = [
        'id' => $rowUserAddress['id'],
        'name' => $rowUserAddress['name'],
        'email' => $rowUserAddress['email'],
        'mobile' => $rowUserAddress['mobile'],
        'road' => $rowUserAddress['road'],
        'building' => $rowUserAddress['building'],
        'houseNo' => $rowUserAddress['houseNo'],
        'floor' => $rowUserAddress['floor'],
        'region' => $rowUserAddress['region'],
        'moreinfor' => $rowUserAddress['moreinfor'],
        'default1' => $rowUserAddress['is_default'],
    ];
    $responseUserAddress = $addressUserAddress;

    // Fetch ShortCode for the specified branchid
    $stmtShortCode = $conn->prepare("
        SELECT *
        FROM ShortCode
        LIMIT 1
    ");

    $stmtShortCode->execute();
    $resultShortCode = $stmtShortCode->get_result();

    // If no ShortCode was found, return null
    if ($resultShortCode->num_rows == 0) {
        $responseShortCode = null;
    } else {
        // Otherwise, create a ShortCode object
        $rowShortCode = $resultShortCode->fetch_assoc();
        $shortcode = [
            'id' => $rowShortCode['id'],
            'branchid' => $rowShortCode['branchid'],
            'code' => $rowShortCode['code'],
            'AccountReference' => $rowShortCode['AccountReference'],
            'url' => $rowShortCode['url'],
        ];
        $responseShortCode = $shortcode;
    }

    $stmtShortCode->close();

    // Combine the responses into a single array
    $response = [
        'id' => $responseUserAddress['id'],
        'name' => $responseUserAddress['name'],
        'email' => $responseUserAddress['email'],
        'mobile' => $responseUserAddress['mobile'],
        'road' => $responseUserAddress['road'],
        'building' => $responseUserAddress['building'],
        'houseNo' => $responseUserAddress['houseNo'],
        'floor' => $responseUserAddress['floor'],
        'region' => $responseUserAddress['region'],
        'moreinfor' => $responseUserAddress['moreinfor'],
        'default1' => $responseUserAddress['default1'],
        'regionname' => $rowUserAddress['regionname'],
        'shippingFee' => $rowUserAddress['shippingFee'],
        'code' => $responseShortCode['code'],
        'refs' => $responseShortCode['AccountReference'],
        'url' => $responseShortCode['url'],
    ];

}

$stmtUserAddress->close();

// Return the combined response as a JSON response
echo json_encode($response);

$conn->close();
?>
